==> flutter_slick-3.4.13.tar.gz: lib/components/fields/text.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_slick/navigation/logic.dart';
import 'package:provider/provider.dart';

class StandardTextField extends StatefulWidget {
  final String? initialValue;
  final FormFieldValidator<String>? validator;
  final int? minLines;
  final int? maxLines;
  final int? maxLength;
  final TextInputAction? textInputAction;
  final FocusNode? focusNode;
  final Function()? onEditingComplete;
  final TextEditingController? controller;
  final bool enabled;
  final bool autofocus;
  final String labelText;
  final Function(String?) onChanged;
  final GestureTapCallback? onTap;
  final Iterable<String>? autofillHints;
  final InputDecoration? inputDecoration;

  const StandardTextField({
    super.key,
    this.initialValue,
    this.validator,
    this.minLines,
    this.maxLines,
    this.maxLength,
    this.focusNode,
    this.textInputAction,
    this.onEditingComplete,
    this.controller,
    this.enabled = true,
    this.autofocus = false,
    required this.labelText,
    required this.onChanged,
    this.onTap,
    this.autofillHints = const [],
    this.inputDecoration,
  });

  @override
  State<StandardTextField> createState() => _StandardTextFieldState();
}

class _StandardTextFieldState extends State<StandardTextField> {
  String? _currentValue;
  late FocusNode focusNode;

  @override
  void initState() {
    super.initState();

    _currentValue = widget.initialValue;
    focusNode = widget.focusNode ?? FocusNode();
    focusNode.addListener(() {
      if (focusNode.hasFocus) return;
      if (_currentValue != widget.initialValue) {
        Provider.of<NavigationLogic>(context, listen: false).setDirty();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    InputDecoration inputDecoration;
    if (widget.inputDecoration != null) {
      inputDecoration = widget.inputDecoration!.copyWith(
        labelText: widget.labelText,
        enabled: widget.enabled,
      );
    } else {
      inputDecoration = InputDecoration(
        labelText: widget.labelText,
        enabled: widget.enabled,
      );
    }

    return TextFormField(
      initialValue: widget.initialValue,
      onChanged: (value) {
        _currentValue = value;
        widget.onChanged(value);
      },
      validator: widget.validator,
      keyboardType: TextInputType.text,
      decoration: inputDecoration,
      minLines: widget.minLines,
      maxLines: widget.maxLines,
      maxLength: widget.maxLength,
      autofocus: widget.autofocus,
      focusNode: focusNode,
      textInputAction: widget.textInputAction,
      onEditingComplete: widget.onEditingComplete,
      controller: widget.controller,
      onTap: widget.onTap,
      autofillHints: widget.autofillHints,
    );
  }
}

==> flutter_slick-3.5.3.tar.gz: lib/components/fields/text.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_slick/navigation/logic.dart';
import 'package:provider/provider.dart';

class StandardTextField extends StatefulWidget {
  final String? initialValue;
  final FormFieldValidator<String>? validator;
  final int? minLines;
  final int? maxLines;
  final int? maxLength;
  final TextInputAction? textInputAction;
  final FocusNode? focusNode;
  final Function()? onEditingComplete;
  final TextEditingController? controller;
  final bool enabled;
  final bool autofocus;
  final String? labelText;
  final Function(String?) onChanged;
  final GestureTapCallback? onTap;
  final Iterable<String>? autofillHints;
  final InputDecoration? decoration;
  final TextStyle? style;

  const StandardTextField({
    super.key,
    this.initialValue,
    this.validator,
    this.minLines,
    this.maxLines,
    this.maxLength,
    this.focusNode,
    this.textInputAction,
    this.onEditingComplete,
    this.controller,
    this.enabled = true,
    this.autofocus = false,
    this.labelText,
    required this.onChanged,
    this.onTap,
    this.autofillHints = const [],
    this.decoration,
    this.style,
  });

  @override
  State<StandardTextField> createState() => _StandardTextFieldState();
}

class _StandardTextFieldState extends State<StandardTextField> {
  String? _currentValue;
  late FocusNode focusNode;

  @override
  void initState() {
    super.initState();

    _currentValue = widget.initialValue;
    focusNode = widget.focusNode ?? FocusNode();
    focusNode.addListener(() {
      if (focusNode.hasFocus) return;
      if (_currentValue != widget.initialValue) {
        Provider.of<NavigationLogic>(context, listen: false).setDirty();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    InputDecoration decoration;
    if (widget.decoration != null) {
      decoration = widget.decoration!.copyWith(
        labelText: widget.labelText,
        enabled: widget.enabled,
      );
    } else {
      decoration = InputDecoration(
        labelText: widget.labelText,
        enabled: widget.enabled,
      );
    }

    return TextFormField(
      initialValue: widget.initialValue,
      onChanged: (value) {
        _currentValue = value;
        widget.onChanged(value);
      },
      style: widget.style,
      validator: widget.validator,
      keyboardType: TextInputType.text,
      decoration: decoration,
      minLines: widget.minLines,
      maxLines: widget.maxLines,
      maxLength: widget.maxLength,
      autofocus: widget.autofocus,
      focusNode: focusNode,
      textInputAction: widget.textInputAction,
      onEditingComplete: widget.onEditingComplete,
      controller: widget.controller,
      onTap: widget.onTap,
      autofillHints: widget.autofillHints,
    );
  }
}
